/*
 * Debug Sub-System (DebugSS) driver for Keystone devices
 *
 * Copyright (C) 2014 Texas Instruments.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#define DRIVER_NAME "debugss_module_drv"
#define DEBUGSS_KM_MAJOR_VERSION 1
#define DEBUGSS_KM_MINOR_VERSION 0
#define DEBUGSS_KM_PATCH_VERSION 1

/* enum defining indexes for all the valid debugss address ranges */
/* For K2H platform */
typedef enum {
    eK2H_DEBUGSS_ADDR_RANGE_IDX0 = 0,
    eK2H_DEBUGSS_ADDR_RANGE_IDX1,
    eK2H_DEBUGSS_ADDR_RANGE_IDX2,
    eK2H_DEBUGSS_ADDR_RANGE_IDX3,
    eK2H_DEBUGSS_ADDR_RANGE_IDX4,
    eK2H_DEBUGSS_ADDR_RANGE_IDX5,
    eK2H_DEBUGSS_NUM_RANGE_MAX
}ek2h_debugss_addr_range_idx;

/* Note: A new platform specific enum needs to be added here, whenever support
   for a new platform needs to be added */

/* Static data structure for storing all the valid debugss address ranges */
/* For K2H platform */
static unsigned int k2h_debugss_addr_range[eK2H_DEBUGSS_NUM_RANGE_MAX][2] = {
    {0x01100000, 0x0110FFFC}, /* ARM STM stimulus port address range */      
    {0x01D00000, 0x01DE807C}, /* CP tracers address range */
    {0x02440000, 0x024B3FFC}, /* C66x CorePAC ADTF address range */
    {0x027D0000, 0x02857FFC}, /* Embedded Trace Buffer (ETB) address range */
    {0x03000000, 0x030FFFFC}, /* DebugSS configuration address range */
    {0x20000000, 0x200FFFFC}  /* STM configuration address range */
};

/* Note: A new platform specific static data structure needs to be added here, 
whenever support for a new platform needs to be added */

//JTAGID-part numbers based identifiers
#define TCI6614_JTAGID_PARTNUMBER       (0xB962)
#define C66AK2Hxx_JTAGID_PARTNUMBER      (0xB981)
#define C66AK2Exx_JTAGID_PARTNUMBER      (0xB9A6)
#define TCI6630K2L_JTAGID_PARTNUMBER    (0xB9A7)

/* enum for supported device/platform types */
typedef enum {
    eNotSupported_device = -1, /* device is Not supported */
    e66AK2Hxx_device = 0, /* device is 66AK2Hxx, TCI6636K2H, TCI6634K2K, TCI6638K2K and 6636AK2Hxx */
    eTCI6614_device, /* device is TCI6614 */
    e66AK2Exx_device, /* device is 66AK2Exx */
    eTCI6630K2L_device, /* device is TCI6630 */
    eMAX_DEVICES
}edevice_type;

/* Macros for BOOTCFG JTAGID register */
#define BOOTCFG_BASE_ADDR            (0x02620000)
#define BOOTCFG_JTAGID_REG           (0x18) 
  
